@@ -1,5 +1,5 @@
-import sys, os
-from PyQt4 import QtCore, QtGui
+import os
+from PyQt5 import QtCore, QtGui, QtWidgets
 
 from apt_offline_gui.Ui_AptOfflineQtMain import Ui_AptOfflineMain
 
@@ -8,9 +8,9 @@ from apt_offline_gui.AptOfflineQtFetch import AptOfflineQtFetch
 from apt_offline_gui.AptOfflineQtInstall import AptOfflineQtInstall
 from apt_offline_gui.AptOfflineQtAbout import AptOfflineQtAbout
 
-class AptOfflineQtMain(QtGui.QMainWindow):
+class AptOfflineQtMain(QtWidgets.QMainWindow):
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+        QtWidgets.QWidget.__init__(self, parent)
         self.ui = Ui_AptOfflineMain()
         self.ui.setupUi(self)
         
@@ -25,38 +25,52 @@ class AptOfflineQtMain(QtGui.QMainWindow):
         self.CreateButtonHoverHelp()
         
     def ConfigureCreateProfile(self):
-        QtCore.QObject.connect(self.ui.menuCreateProfile, QtCore.SIGNAL("triggered()"), self.CreateProfile)
-        QtCore.QObject.connect(self.ui.createProfileButton,QtCore.SIGNAL("clicked()"), self.CreateProfile)
+        #QtCore.QObject.connect(self.ui.menuCreateProfile, QtCore.SIGNAL("triggered()"), self.CreateProfile)
+        #QtCore.QObject.connect(self.ui.createProfileButton,QtCore.SIGNAL("clicked()"), self.CreateProfile)
+
+        self.ui.menuCreateProfile.triggered.connect(self.CreateProfile)
+        self.ui.createProfileButton.clicked.connect(self.CreateProfile)
         # Create an object and do not show it
         self.createProfileDialog = AptOfflineQtCreateProfile()
         # setup hover hack
         self.ui.createProfileButton.installEventFilter(self)
         
     def ConfigureDownload(self):
-        QtCore.QObject.connect(self.ui.menuDownload, QtCore.SIGNAL("triggered()"), self.DownloadPackagesUpgrades)
-        QtCore.QObject.connect(self.ui.downloadButton, QtCore.SIGNAL("clicked()"), self.DownloadPackagesUpgrades)
+        #QtCore.QObject.connect(self.ui.menuDownload, QtCore.SIGNAL("triggered()"), self.DownloadPackagesUpgrades)
+        #QtCore.QObject.connect(self.ui.downloadButton, QtCore.SIGNAL("clicked()"), self.DownloadPackagesUpgrades)
+
+        self.ui.menuDownload.triggered.connect(self.DownloadPackagesUpgrades)
+        self.ui.downloadButton.clicked.connect(self.DownloadPackagesUpgrades)
         # Create an object for download dialog
         self.createDownloadDialog = AptOfflineQtFetch()
         # setup hover hack
         self.ui.downloadButton.installEventFilter(self)
     
     def ConfigureInstall(self):
-        QtCore.QObject.connect(self.ui.menuInstall, QtCore.SIGNAL("triggered()"), self.InstallPackagesUpgrades)
-        QtCore.QObject.connect(self.ui.restoreButton, QtCore.SIGNAL("clicked()"), self.InstallPackagesUpgrades)
+        #QtCore.QObject.connect(self.ui.menuInstall, QtCore.SIGNAL("triggered()"), self.InstallPackagesUpgrades)
+        #QtCore.QObject.connect(self.ui.restoreButton, QtCore.SIGNAL("clicked()"), self.InstallPackagesUpgrades)
+
+        self.ui.menuInstall.triggered.connect(self.InstallPackagesUpgrades)
+        self.ui.restoreButton.clicked.connect(self.InstallPackagesUpgrades)
         # Create an object for Install dialog
         self.createInstallDialog = AptOfflineQtInstall()
         # setup hover hack
         self.ui.restoreButton.installEventFilter(self)
 
     def ConfigureAbout(self):
-        QtCore.QObject.connect(self.ui.menuAbout, QtCore.SIGNAL("triggered()"), self.ShowAbout)
-        QtCore.QObject.connect(self.ui.menuHelp_2, QtCore.SIGNAL("triggered()"), self.ShowHelp)
+        #QtCore.QObject.connect(self.ui.menuAbout, QtCore.SIGNAL("triggered()"), self.ShowAbout)
+        #QtCore.QObject.connect(self.ui.menuHelp_2, QtCore.SIGNAL("triggered()"), self.ShowHelp)
+
+        self.ui.menuHelp_2.triggered.connect(self.ShowAbout)
+        self.ui.menuAbout.triggered.connect(self.ShowAbout)
         # Create an object for About Dialog
         self.createAboutDialog = AptOfflineQtAbout()
         
     def ConfigureMenuExit(self):
-        QtCore.QObject.connect(self.ui.menuExit, QtCore.SIGNAL("triggered()"), self.ExitApp)
-        QtCore.QObject.connect(self.ui.exitButton, QtCore.SIGNAL("clicked()"), self.ExitApp)
+        #QtCore.QObject.connect(self.ui.menuExit, QtCore.SIGNAL("triggered()"), self.ExitApp)
+        #QtCore.QObject.connect(self.ui.exitButton, QtCore.SIGNAL("clicked()"), self.ExitApp)
+        self.ui.menuExit.triggered.connect(self.ExitApp)
+        self.ui.exitButton.clicked.connect(self.ExitApp)
 
     def eventFilter(self,target,event):
         # hover hack for 3 buttons
@@ -76,10 +90,10 @@ class AptOfflineQtMain(QtGui.QMainWindow):
     def CreateProfile(self):
         try:
                 if os.geteuid() != 0:
-                        QtGui.QMessageBox.critical(self, "Error", "You need to run with root privileges!")
+                        QtWidgets.QMessageBox.critical(self, "Error", "You need to run with root privileges!")
                         return
         except AttributeError:
-                QtGui.QMessageBox.critical(self, "Error", "This is supported only on Unix like systems with apt installed.")
+                QtWidgets.QMessageBox.critical(self, "Error", "This is supported only on Unix like systems with apt installed.")
                 return
         # Code for creating Modal Dialog for Create Profile
         self.createProfileDialog.resetUI()
@@ -93,10 +107,10 @@ class AptOfflineQtMain(QtGui.QMainWindow):
     def InstallPackagesUpgrades(self):
         try:
                 if os.geteuid() != 0:
-                        QtGui.QMessageBox.critical(self, "Error", "You need to run with root privileges!")
+                        QtWidgets.QMessageBox.critical(self, "Error", "You need to run with root privileges!")
                         return
         except AttributeError:
-                QtGui.QMessageBox.critical(self, "Error", "This is supported only on Unix like systems with apt installed.")
+                QtWidgets.QMessageBox.critical(self, "Error", "This is supported only on Unix like systems with apt installed.")
                 return
         # Code for creating Modal Dialog for Installing Packages/Upgrades
         self.createInstallDialog.show()
@@ -106,7 +120,7 @@ class AptOfflineQtMain(QtGui.QMainWindow):
         self.createAboutDialog.show()
         
     def ShowHelp(self):
-        QtGui.QMessageBox.information(self, "Info", "Please refer to the apt-offline(8) man page")
+        QtWidgets.QMessageBox.information(self, "Info", "Please refer to the apt-offline(8) man page")
 
     def CreateButtonHoverHelp(self):
         pass
